==> jsoneditor-5.0.0.tgz: package/docs/shortcut_keys.md <==
# Shortcut keys

## Tree Editor

Key                     | Description
----------------------- | ------------------------------------------------
Alt+Arrows              | Move the caret up/down/left/right between fields
Shift+Alt+Arrows        | Move current field or selected fields up/down/left/right
Shift+Arrow Up/Down     | Select multiple fields
Ctrl+D                  | Duplicate field
Ctrl+Del                | Remove field
Ctrl+Enter              | Open link when on a field containing an url
Ctrl+Ins                | Insert a new field with type auto
Ctrl+Shift+Ins          | Append a new field with type auto
Ctrl+E                  | Expand or collapse field
Alt+End                 | Move the caret to the last field
Ctrl+F                  | Find
F3, Ctrl+G              | Find next
Shift+F3, Ctrl+Shift+G  | Find previous
Alt+Home                | Move the caret to the first field
Ctrl+M                  | Show actions menu
Ctrl+Z                  | Undo last action
Ctrl+Shift+Z            | Redo


## Code Editor

The code editor is powered by [Ace Editor](http://ace.c9.io/). This editor's
shortcut keys are described here:

https://github.com/ajaxorg/ace/wiki/Default-Keyboard-Shortcuts

Additionally, there are shortcut keys to format/compact the code:

Key                     | Description
----------------------- | ------------------------------------------------
Ctrl+\                  | Format JSON data, set proper indentation
Ctrl+Shift+\            | Compact JSON data, remove all whitespace

==> jsoneditor-5.14.1.tgz: package/docs/shortcut_keys.md <==
# Shortcut keys

## Tree Editor

Key                     | Description
----------------------- | ------------------------------------------------
Alt+Arrows              | Move the caret up/down/left/right between fields
Ctrl+Shift+Arrow Up/Down| Select multiple fields
Shift+Alt+Arrows        | Move current field or selected fields up/down/left/right
Ctrl+D                  | Duplicate field
Ctrl+Del                | Remove field
Ctrl+Enter              | Open link when on a field containing an url
Ctrl+Ins                | Insert a new field with type auto
Ctrl+Shift+Ins          | Append a new field with type auto
Ctrl+E                  | Expand or collapse field
Alt+End                 | Move the caret to the last field
Ctrl+F                  | Find
F3, Ctrl+G              | Find next
Shift+F3, Ctrl+Shift+G  | Find previous
Alt+Home                | Move the caret to the first field
Ctrl+M                  | Show actions menu
Ctrl+Z                  | Undo last action
Ctrl+Shift+Z            | Redo


## Code Editor

The code editor is powered by [Ace Editor](http://ace.c9.io/). This editor's
shortcut keys are described here:

https://github.com/ajaxorg/ace/wiki/Default-Keyboard-Shortcuts

Additionally, there are shortcut keys to format/compact the code:

Key                     | Description
----------------------- | ------------------------------------------------
Ctrl+\                  | Format JSON data, set proper indentation
Ctrl+Shift+\            | Compact JSON data, remove all whitespace
